##  Keyboard Accessibility
You can navigate and perform actions in table view using keyboard keys. Use the arrow keys to move through cells, and press Enter to select and edit a cell. Clicking Enter on a column header will sort the table by that column.
